@@ -410,7 +410,7 @@ class DeprelSeqTagger(FeatTagger):
               rnn_emb_dim=None, cnn_emb_dim=None, cnn_kernels=range(1, 7),
               upos_emb_dim=300, emb_out_dim=512, lstm_hidden_dim=256,
               lstm_layers=2, lstm_do=0, bn1=True, do1=.2, bn2=True, do2=.5,
-              bn3=True, do3=.4, seed=None, start_time=None,
+              bn3=True, do3=.4, seed=None, start_time=None, keep_embs=False,
               log_file=LOG_FILE):
         """Creates and trains the DEPREL tagger model.
 
@@ -534,6 +534,11 @@ class DeprelSeqTagger(FeatTagger):
         **start_time** (`float`): result of `time.time()` to start with. If
         `None` (default), the arg will be init anew.
 
+        **keep_embs**: by default, after creating `Dataset` objects, we remove
+        word embedding models to free memory. With `keep_embs=False` this
+        operation is omitted, and you can use `.embs` attribute for share
+        embeddings models with other objects.
+
         **log_file**: a stream for info messages. Default is `sys.stdout`.
 
         The method returns the train statistics.
