@@ -11,14 +11,14 @@ from corpuscula import CorpusDict
 from difflib import SequenceMatcher, get_close_matches
 from junky import get_func_params
 from mordl.base_tagger import BaseTagger
-from mordl.defaults import BATCH_SIZE, LOG_FILE, TRAIN_BATCH_SIZE
+from mordl.defaults import BATCH_SIZE, CDICT_COEF_THRESH, LOG_FILE, \
+                           TRAIN_BATCH_SIZE
 from mordl.feat_tagger_model import FeatTaggerModel
 import time
 
 _OP_C_ASIS = 'asis'
 _OP_C_TITLE = 'title'
 _OP_C_LOWER = 'lower'
-_CDICT_COEF_THRESH = .99
 
 
 class LemmaTagger(BaseTagger):
@@ -272,9 +272,10 @@ class LemmaTagger(BaseTagger):
                 if use_cdict_coef not in [None, False]:
                     str_from_, coef = \
                         cdict.predict_lemma(str_from, upos, isfirst=isfirst)
-                    if coef >= _CDICT_COEF_THRESH \
-                                   if use_cdict_coef is True else \
-                               use_cdict_coef:
+                    if coef is not None \
+                   and coef >= (CDICT_COEF_THRESH \
+                                    if use_cdict_coef is True else \
+                                use_cdict_coef):
                         str_from = str_from_
                     else:
                         str_from_ = None
@@ -311,7 +312,7 @@ class LemmaTagger(BaseTagger):
                 isfirst = True
                 for token in sentence_:
                     id_, form = token['ID'], token['FORM']
-                    if token and '-' not in id_:
+                    if form and '-' not in id_:
                         token[self._field] = \
                             apply_editops(form, token['UPOS'],
                                           token[self._field], isfirst=isfirst)
@@ -382,7 +383,7 @@ class LemmaTagger(BaseTagger):
               rnn_emb_dim=None, cnn_emb_dim=None, cnn_kernels=range(1, 7),
               upos_emb_dim=300, emb_out_dim=512, lstm_hidden_dim=256,
               lstm_layers=3, lstm_do=0, bn1=True, do1=.2, bn2=True, do2=.5,
-              bn3=True, do3=.4, seed=None, start_time=None,
+              bn3=True, do3=.4, seed=None, start_time=None, keep_embs=False,
               log_file=LOG_FILE):
         """Creates and trains a LEMMA prediction model.
 
@@ -506,6 +507,11 @@ class LemmaTagger(BaseTagger):
         **start_time** (`float`): result of `time.time()` to start with. If
         `None` (default), the arg will be init anew.
 
+        **keep_embs**: by default, after creating `Dataset` objects, we remove
+        word embedding models to free memory. With `keep_embs=False` this
+        operation is omitted, and you can use `.embs` attribute for share
+        embeddings models with other objects.
+
         **log_file**: a stream for info messages. Default is `sys.stdout`.
 
         The method returns the train statistics.
